summaryrefslogtreecommitdiffstats
path: root/cpukit/libmisc/dumpbuf/dumpbuf.c
diff options
context:
space:
mode:
authorJoel Sherrill <joel.sherrill@OARcorp.com>2007-03-12 20:23:58 +0000
committerJoel Sherrill <joel.sherrill@OARcorp.com>2007-03-12 20:23:58 +0000
commitdfb3c2b71f6d8d573bdadfce99d72ec7af1184a4 (patch)
tree3346f18f8902452f813df06c64349fb08b867394 /cpukit/libmisc/dumpbuf/dumpbuf.c
parent2007-03-12 Joel Sherrill <joel@OARcorp.com> (diff)
downloadrtems-dfb3c2b71f6d8d573bdadfce99d72ec7af1184a4.tar.bz2
2007-03-12 Joel Sherrill <joel@OARcorp.com>
* libmisc/dumpbuf/dumpbuf.c, libmisc/dumpbuf/dumpbuf.h: Rename Dump_Buffer to rtems_print_buffer.
Diffstat (limited to 'cpukit/libmisc/dumpbuf/dumpbuf.c')
-rw-r--r--cpukit/libmisc/dumpbuf/dumpbuf.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/cpukit/libmisc/dumpbuf/dumpbuf.c b/cpukit/libmisc/dumpbuf/dumpbuf.c
index 120a464a90..c5c4746c16 100644
--- a/cpukit/libmisc/dumpbuf/dumpbuf.c
+++ b/cpukit/libmisc/dumpbuf/dumpbuf.c
@@ -1,5 +1,5 @@
/*
- * COPYRIGHT (c) 1997.
+ * COPYRIGHT (c) 1997-2007.
* On-Line Applications Research Corporation (OAR).
*
* The license and distribution terms for this file may in
@@ -19,7 +19,7 @@
#include <rtems/dumpbuf.h>
/*
* Put the body below Dump_Buffer so it won't get inlined.
*/
static inline void Dump_Line(
@@ -27,7 +27,7 @@ static inline void Dump_Line(
int length
);
-void Dump_Buffer(
+void rtems_print_buffer(
unsigned char *buffer,
int length
)
@@ -19,7 +19,7 @@
#include <rtems/dumpbuf.h>
/*
- * Put the body below Dump_Buffer so it won't get inlined.
+ * Put the body below rtems_print_buffer so it won't get inlined.
*/
static inline void Dump_Line(